@@ -1,8 +1,12 @@
 from ui.Widget import Widget
+from utils.Observable import Observable
 import theme
 
 
-class PrefsCard(Widget):
+class PrefsCard(Widget, Observable):
+    
+    OBS_SCAN_MEDIA = 0
+    
 
     def __init__(self, esens, title):
     
